{# Copyright (C) 2021 CERN. Copyright (C) 2021 Graz University of Technology. Copyright (C) 2021 TU Wien. Copyright (C) 2026 University of Münster. Invenio App RDM is free software; you can redistribute it and/or modify it under the terms of the MIT License; see LICENSE file for more details. #} {%- set title = _("Search guide") %} {%- extends config.BASE_TEMPLATE %} {%- block page_body %}

## Suchanleitung

Diese Anleitung erklärt anhand von leicht verständlichen Beispielen, wie man erweiterte Suchanfragen stellt.

### Einfache Suche (ein oder mehrere Begriffe)

Beispiel: `open science`

Die Ergebnisse entsprechen Datensätzen, die einen der Begriffe `open` oder `science` in einem beliebigen Feld beinhalten. Beachten Sie, dass eine Wortstamm-Erkennung angewendet wird, sodass z. B. science auch mit sciences übereinstimmt. Die Suchergebnisse werden mithilfe eines Algorithmus sortiert, der Ihre Suchbegriffe berücksichtigt. Sie können das Vorhandensein beider Begriffe entweder mit dem `+`- oder dem `AND`-Operator erzwingen:

Beispiele: `+open +science` oder `open AND science`

Sie können das Nichtvorhandensein eines oder mehrerer Begriffe mit dem `-`- oder dem `NOT`-Operator erzwingen:

Beispiele: `-open +science` oder `NOT open AND science`

### Phrasensuche

Beispiel: `"open science"`

Die Ergebnisse entsprechen Datensätzen mit der Phrase `open science` in einem beliebigen Feld.

### Feldsuche

Beispiel: `metadata.title:open`

Die Ergebnisse stimmen mit Datensätzen überein, bei denen das Feld `metadata.title` den Begriff `open` enthält. Wenn Sie nach mehreren Begriffen im Titel suchen möchten, müssen Sie die Begriffe mit Klammern gruppieren:

Beispiel: `metadata.title:(open science)`

Die vollständige Liste der Felder, die Sie durchsuchen können, finden Sie in der InvenioRDM-Dokumentation: https://inveniordm.docs.cern.ch/reference/metadata/#metadata .

### Kombinierte einfache, Phrasen- oder Feldsuche

Beispiel: `+metadata.title:"open science" -metadata.title:policy` oder z. B. `metadata.title:(-open +science)`

Sie können einfache, Phrasen- und Feldsuchen kombinieren, um erweiterte Suchanfragen zu konstruieren.

### Bereichssuche

Beispiel: `metadata.publication_date:[2017 TO 2018]` (Achtung: `TO` muss großgeschrieben werden.)

Die Ergebnisse entsprechen allen Datensätzen mit einem Veröffentlichungsdatum zwischen 2017-01-01 und 2018-01-01 (beide Daten eingeschlossen).

Beachten Sie, dass partielle Daten zu vollständigen Daten ergänzt werden, z. B.:

- `2017` wird ergänzt zu `2017-01-01`
- `2017-06` wird ergänzt zu `2017-06-01`

Verwenden Sie eckige Klammern (`[]`) für einschließende Bereiche und geschweifte Klammern (`{}`) für ausschließende Bereiche, z. B.:

- `[2017 TO 2018}` ist aufgrund der Datumsergänzung und der exklusiven Obergrenze äquivalent zu `[2017-01-01 TO 2017-12-31]`.

Beispiele für andere Bereiche:

- `metadata.publication_date:{* TO 2017-01-01}`: Alle Tage bis 2017.
- `metadata.publication_date:[2017-01-01 TO *]`: Alle Tage ab 2017.

### Ranking/Sortierung

Standardmäßig werden alle Suchergebnisse mithilfe eines internen Ranking-Algorithmus sortiert, der jedes Suchergebnis anhand Ihrer Suchparameter bewertet. Sowohl in der Benutzeroberfläche als auch in der REST-API ist es möglich, die Ergebnisse zu sortieren nach:

- Beste Übereinstimmung
- Neuste
- Älteste
- Am häufigsten angesehen
- Am häufigsten heruntergeladen

### Reguläre Ausdrücke

Reguläre Ausdrücke sind eine mächtige Sprache für den Mustervergleich, mit der man nach bestimmten Mustern in einem Feld suchen kann. Wenn Sie zum Beispiel alle Datensätze mit dem DOI-Präfix `10.5281` finden wollen, können Sie eine Suche mit regulären Ausdrücken verwenden:

Beispiel: `pids.doi.identifier:/10\.5281.*/`

Vorsicht: Der reguläre Ausdruck muss mit dem gesamten Feldwert übereinstimmen. Weitere Einzelheiten finden Sie auf der englischsprachigen Website "Regular expression syntax" .

### Fehlende Werte

Es ist möglich, mit den Feldnamen `_exists_` und `NOT _exists_` nach Datensätzen zu suchen, bei denen ein Wert fehlt oder vorhanden ist.

Beispiel:

- `NOT _exists_:metadata.additional_titles` (alle Datensätze ohne `metadata.additional_titles`)
- `_exists_:metadata.creators` (alle Datensätze mit `metadata.creators`)

### Erweiterte Konzepte

#### Boosten

Sie können den Boost-Operator `^` verwenden, wenn ein Begriff relevanter ist als ein anderer. Sie können z. B. nach allen Datensätzen suchen, die die Phrase `open science` entweder im `title`- oder im `description`-Feld enthalten, aber Datensätze mit der Phrase im `title`-Feld höher einstufen:

Beispiel: `metadata.title:"open science"^5 metadata.description:"open science"`

#### Unschärfe

Mit dem Fuzzy-Operator `~` können Sie nach Begriffen suchen, die Ihrem Suchbegriff ähnlich, aber nicht exakt gleich sind.

Beispiel: `oepn~`

Die Ergebnisse entsprechen Datensätzen mit ähnlichen Begriffen, die auch für z.B. `open` Suchtreffer ergeben würden (z. B. mit Rechtschreibfehlern).

#### Näherungssuche

Eine Phrasensuche wie `"open science"` erwartet standardmäßig alle Begriffe in genau der gleichen Reihenfolge und würde daher z. B. nicht auf einen Datensatz passen, der die Phrase `"open access and science"` enthält. Eine Näherungssuche erlaubt, dass die Begriffe nicht in der exakten Reihenfolge stehen und auch andere Begriffe dazwischen enthalten können. Der Grad der Flexibilität wird durch eine Ganzzahl angegeben:

Beispiel: `"open science"~5`

#### Platzhalter ("Wildcards")

Sie können Platzhalter in Suchbegriffen verwenden, um

- ein einzelnes Zeichen (`?`-Operator) oder
- kein bis mehrere Zeichen (`*`-Operator)

zu ersetzen.

Beispiel: `ope? scien*`

Platzhaltersuchen können langsam sein und sollten nach Möglichkeit vermieden werden.

{%- endblock page_body %}